'use strict';

var fs = require('fs');
var path = require('path');
var os = require('os');
var debug = require('debug')('logpath');

function getAppName() {
  var packageFile = path.join(process.cwd(), 'package.json');
  var packageData = JSON.parse(fs.readFileSync(packageFile, 'utf-8'));
  return packageData.productName || packageData.name;
}

function createDirIfNotExists() {
  var dirPath = void 0;
  try {
    dirPath = path.join.apply(path, arguments);
    if (!fs.existsSync(dirPath)) {
      fs.mkdirSync(dirPath);
    }
    return dirPath;
  } catch (err) {
    debug(err.message);
  }
  return false;
}

function getDefaultLogDirPath() {
  return createDirIfNotExists(process.cwd(), 'logs');
}

function getPlatformLogDirPath(appName) {
  var homeDir = os.homedir ? os.homedir() : process.env.HOME;
  switch (process.platform) {
    case 'linux':
      {
        return createDirIfNotExists('/var/log', appName) || createDirIfNotExists(process.env.XDG_CONFIG_HOME, appName) || createDirIfNotExists(homeDir, '.config', appName) || createDirIfNotExists(process.env.XDG_DATA_HOME, appName) || createDirIfNotExists(homeDir, '.local', 'share', appName);
      }
    case 'darwin':
      {
        return createDirIfNotExists(homeDir, 'Library', 'Logs', appName) || createDirIfNotExists(homeDir, 'Library', 'Application Support', appName);
      }
    case 'win32':
      {
        return createDirIfNotExists(process.env.APPDATA, appName) || createDirIfNotExists(homeDir, 'AppData', 'Roaming', appName);
      }
    default:
      {
        throw new Error('Unsupported platform: \'' + process.platform + '\'');
      }
  }
}

var logdirpath = {
  createAndGetLogDirPath: function createAndGetLogDirPath() {
    var appName = void 0;
    var logDirPath = void 0;
    try {
      appName = getAppName();
      try {
        logDirPath = getPlatformLogDirPath(appName);
      } catch (err) {
        logDirPath = getDefaultLogDirPath();
      }
    } catch (err) {
      debug('Could not retrieve app name from package.json');
      debug(err.message);
      logDirPath = getDefaultLogDirPath();
    }
    if (!logDirPath) {
      throw new Error('Could not create logs directory');
    }
    debug('Saving logs to: ' + logDirPath);
    return logDirPath;
  }
};

module.exports = logdirpath;